version 18
use low, clear

/* Create a document with a footer*/
putdocx begin, footer(foot1) 

/* Add page numbers to the footer */
putdocx paragraph, tofooter(foot1)
putdocx pagenumber
putdocx text ("/")
putdocx pagenumber, totalpages 

putdocx paragraph, style(Heading1)
putdocx text ("Data")

putdocx textblock begin
We have data on birthweights from Hosmer, Lemeshow, and Sturdivant(2013, 24). This dataset includes some demographic information on each infant's mother, 
such as her age and race. We also have relevant medical history, including her 
weight, history of hypertension and premature labor, and the number of 
physician visits during her first trimester.
putdocx textblock end

putdocx paragraph, style(Heading1)
putdocx text ("Summary statistics")

summarize bwt
putdocx textblock begin
We have the recorded weight for <<dd_docx_display: r(N)>> babies with an 
average birthweight of <<dd_docx_display: %5.2f r(mean)>> grams.
putdocx textblock end

local total = r(N)
count if smoke==1

putdocx textblock append
 There are <<dd_docx_display: r(N)>> mothers who smoked during pregnancy, and
<<dd_docx_display: `total'-r(N)>> who did not. Below we graph the mean 
birthweight for babies with mothers who smoke versus those who do not, 
separately for mothers with and without a history of hypertension.
putdocx textblock end

graph hbar bwt, over(ht) over(smoke) asyvars ///
		ytitle(Average birthweight (grams)) title(Baby birthweights) ///
		subtitle(by mother's smoking status and history of hypertension)
graph export bweight.png, replace

putdocx paragraph
putdocx image bweight.png, width(4) 

putdocx pagebreak

putdocx paragraph, style(Heading1)
putdocx text ("Regression results")

/* We've added a link to an article on birth weight. */
putdocx textblock begin
A review of the literature on birth weights shows that advanced maternal age is
 associated with an increased probability of low birth weight. For a recent example, see
<<dd_docx_display hyperlink("https://academic.oup.com/aje/article/186/11/1219/3858068"):" Goisis et al. (2017)">>.
 Below, we fit a linear regression of birthweight on the mother's age and whether she smokes. 
putdocx textblock end

regress bwt i.smoke age, noheader cformat(%9.2f)
putdocx table bweight = etable, title("Linear regression of birthweight")
putdocx table bweight(3,.), drop 
putdocx table bweight(2 4,.), shading(lightgray)

putdocx textblock begin
We find that on average, infants whose mothers smoked tend to weigh less.
putdocx textblock end

putdocx save bwreport,replace



